# Generated by roxygen2: do not edit by hand

S3method(tmapGetShapeMeta1,linnet)
S3method(tmapGetShapeMeta1,sfnetwork)
S3method(tmapGetShapeMeta2,linnet)
S3method(tmapGetShapeMeta2,sfnetwork)
S3method(tmapGridDataPlot,tm_data_edges)
S3method(tmapGridDataPlot,tm_data_network)
S3method(tmapGridDataPlot,tm_data_nodes)
S3method(tmapLeafletDataPlot,tm_data_edges)
S3method(tmapLeafletDataPlot,tm_data_network)
S3method(tmapLeafletDataPlot,tm_data_nodes)
S3method(tmapShape,sfnetwork)
S3method(tmapSubsetShp,linnet)
S3method(tmapSubsetShp,sfnetwork)
export(opt_tm_edges)
export(opt_tm_nodes)
export(tm_edges)
export(tm_network)
export(tm_nodes)
export(tmapMapboxDataPlot.tm_data_edges)
export(tmapMapboxDataPlot.tm_data_network)
export(tmapMapboxDataPlot.tm_data_nodes)
export(tmapMaplibreDataPlot.tm_data_edges)
export(tmapMaplibreDataPlot.tm_data_network)
export(tmapMaplibreDataPlot.tm_data_nodes)
import(data.table)
import(sf)
import(tmap)
importFrom(lwgeom,st_linesubstring)
