#' Extension for tmap: networks
#'
#' Networks from sfnetworks are supported and several network specifc layer functions are added
#'
#' @author Martijn Tennekes \email{mtennekes@@gmail.com}
#' @import data.table
#' @concept GIS
#' @concept thematic maps
#' @concept statistical maps
#' @concept choropleth
#' @concept bubble map
"_PACKAGE"
